# $Id: AstronomicalHolographyScript.py 211525 2014-11-25 08:00:24Z nphillip $
# Astronomical Holography Standard Script

import Observation.SchedulingBlock
import Control

sb = Observation.SchedulingBlock.SchedulingBlock()
array = getArray();
array.beginExecution()
executionStatus = Control.FAIL # Assume its bad unless we get to the end

try:
   ah = array.getAstronomicalHolographyObservingMode()
   
   # This gets all targets that have holography parameters
   allTargets = sb.getHolographyTargetList()
   
   for tgt in allTargets:
      # skip targets that will set in the next 10 minutes
      if not ah.isObservable(tgt.getSource(), '10min'):
          continue
      ah.beginScan();

      # This moves all antennas to the source, tunes the front-end and
      # configures/calibrates the correlator. The antennas should be
      # tracking, the receivers locked and the correlator configured
      # when this function completes  The signal levels are set to their
      # optimum as well.

      ah.setTarget(tgt.getSource(), tgt.getSpectralSpec());
      ah.waitUntilOnSource()
      ah.optimizeSignalLevels()

      # Setup the overall parameters of the holography scan.
      ah.setReferenceAntennas(sb.getExpertParameter('Reference Antennas'));
      subscanSize = tgt.getSubscanSize()
      ah.setSubscanDuration(subscanSize, tgt.getSubscanSpeed());

      if (tgt.getSubscanDirection() == 'AzScan'):
         ah.setAzimuthSubscans()
      else:
         ah.setElevationSubscans()

      if (tgt.getUniDirectionalSubscans()):
         ah.setUniDirectionalSubscans()
      else:
         ah.setBiDirectionalSubscans()

      # Now do the subscans
      numSubscans = tgt.getNumSubscans()
      numSubscansPerCal = tgt.getSubscansPerCal()
      subscansDone = 0
      while subscansDone < numSubscans:
         ah.doPhaseCal(tgt.getCalTime());
         numSubscansToDo =  min(numSubscansPerCal, numSubscans-subscansDone);
         perpOffsets =  [subscanSize * ((subscansDone + s + 0.5)/numSubscans - 0.5) for s in range(numSubscansToDo)]
         ah.doSubscans(perpOffsets)
         subscansDone += numSubscansToDo;

      #Finish up with a phaseCal
      ah.doPhaseCal(tgt.getCalTime());
      ah.endScan();

   executionStatus = Control.SUCCESS   
finally:
   # Call endScan if necessary. Eventually this will be unnecessary
   if (executionStatus == Control.FAIL) and ('ah' in vars()):
      ah.endScan();
   # This also shuts down the observing mode that stops the antenna moving.
   array.endExecution(executionStatus, 'Astronomical holography')
