#! /usr/bin/env python
#*******************************************************************************
# ALMA - Atacama Large Millimiter Array
# (c) Associated Universities Inc., 2009 
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
#
# "@(#) $Id: ObsCalPadDelay.py 214236 2015-02-06 05:12:53Z nphillip $"

#
# forcing global imports is due to an OSS problem
#
global copy
import copy

global CCL
import CCL.Global

global Control
import Control

global ControlExceptionsImpl
import ControlExceptionsImpl

global Observation
import Observation.DelayCalTarget
import Observation.SSRTuning
import Observation.ObsCalBase


class ObsCalPadDelay(Observation.ObsCalBase.ObsCalBase):

    def parseOptions(self):
        self.repeatCount             = self.getExpertParameterOrDefault("RepeatCount", int, 2)
        self.pointingSubscanDuration = self.getExpertParameterOrDefault("PointingSubscanDuration", float, 5.76)
        self.atmSubscanDuration      = self.getExpertParameterOrDefault("AtmSubscanDuration", float, 5.76)
        self.sbrSubscanDuration      = self.getExpertParameterOrDefault("SBRSubscanDuration", float, 5.76)
        self.focusSubscanDuration    = self.getExpertParameterOrDefault("FocusSubscanDuration", float, 5.76)
        self.dumpDuration            = self.getExpertParameterOrDefault("dumpDuration", float, 0.576)
        self.channelAverageDuration  = self.getExpertParameterOrDefault("channelAverageDuration", float, 0.576)
        # ACA requires more than about 8.5 sec in FDM mode for 16-ant array
        self.integrationDuration     = self.getExpertParameterOrDefault("integrationDuration", float, 9.216)
        #self.atmIntegrationDuration  = self.getExpertParameterOrDefault("AtmIntegrationDuration", float, 0.576)
        self.tpIntegrationDuration   = self.getExpertParameterOrDefault("tpIntegrationDuration", float, 0.016)
        self.elLimit                 = self.getExpertParameterOrDefault("ElLimit", str, "20 deg")
        self.numTargets              = self.getExpertParameterOrDefault("NumTargets", int, 10)
        self.band                    = self.getExpertParameterOrDefault("band", int, 3)
        bbNameStr                    = self.getExpertParameterOrDefault("bbNames", str, "")
        self.bbNames = None
        if bbNameStr is not None and bbNameStr != "":
            self.bbNames = []
            for s in bbNameStr.split(','):
                self.bbNames.append(s)

    def generateTunings(self):
        #
        # For B9/10 its useful to do an all-USB setup to avoid configing the
        # analysis into producing irrelevant LSB delays.
        #
        if self.band == 9:
            # can improve on this a lot by moving LOs around to minimise noise in the USB
            sameBBFreqs = True
            frequency = 668.0
            SBPref = "LSB"
        elif self.band == 10:
            sameBBFreqs = True
            frequency = 852.0
            SBPref = "LSB"
        else:
            sameBBFreqs = False
            frequency = Observation.SSRTuning.bandFreqs_delayMeasurement[self.band]
            SBPref = None
        corrType = self._array.getCorrelatorType()
        self._spectralSpec = self._tuningHelper.GenerateSpectralSpec(
                band = self.band,
                intent = "interferometry_continuum",
                frequency = frequency,
                bbNames = self.bbNames,
                SBPref = SBPref,
                sameBBFreqs = sameBBFreqs,
                corrType = corrType,
                corrMode = "FDM",
                bwd = 4,
                dualMode = False,
                dump = self.dumpDuration,
                channelAverage = self.channelAverageDuration,
                integration = self.integrationDuration)

    def doDelayCal(self):
        src = self._srcPointFocus
        ss = self._spectralSpec
        subscanDuration = 30.0
        try:
            delayCal = Observation.DelayCalTarget.DelayCalTarget(src, ss)
            delayCal.setSubscanDuration(subscanDuration)
            delayCal.setIntegrationTime(1.0)
            self.logInfo('Executing DelayCal on ' + src.sourceName + '...')
            delayCal.execute(self._obsmode)
            self.logInfo('Completed DelayCal on ' + src.sourceName)
        except BaseException, ex:
            print ex
            msg = "Error executing cal survey scans on source %s" % src.sourceName
            self.logError(msg)
            self.closeExecution(ex)
            raise ex


Observation.ObsCalBase.checkArray()

survey = ObsCalPadDelay()
survey.parseOptions()
survey.checkAntennas()
survey.startPrepareForExecution()
survey.generateTunings()
survey.findPointFocusSource()
survey.completePrepareForExecution()
survey.logInfo("Executing DelayCal...")
survey.doDelayCal()
survey.closeExecution()

